@@ -1,8 +1,7 @@
 package Yars::Command::yars_generate_diskmap;
 
-# PODNAME: yars_generate_diskmap
 # ABSTRACT: generate a mapping from servers + hosts to buckets for yars.
-our $VERSION = '0.97_01'; # VERSION
+our $VERSION = '0.86'; # VERSION
 
 
 use strict;
@@ -16,14 +15,14 @@ sub main {
     my $class = shift;
     local @ARGV = @_;
     my %servers;
-    my $default_port = 9001;
+    my $port = 9001;
     my $protocol = 'http';
     GetOptions(
-        'port|p=i'   => \$default_port,
+        'port|p=i'   => \$port,
         'protocol=s' => \$protocol,
         'help|h'     => sub { pod2usage({ -verbose => 2}) },
         'version'    => sub {
-            say 'Yars version ', ($Yars::VERSION // 'dev');
+            say 'ACPS::Release version ', ($ACPS::Release::VERSION // 'dev');
             exit 1;
         },
     ) || pod2usage(1);
@@ -31,14 +30,9 @@ sub main {
     my @all;
     while (<>) {
         chomp;
-        s/#.*$//;        # remove comments
-        next if /^\s*$/; # skip empty lines
         my ($host,$disk) = split;
-        my $port;
-        $port = $1 if $host =~ s/:(\d+)$//;
-        $host =~ tr/a-zA-Z0-9.\-//dc;
-        $host = join ':', $host, $port if $port;
-        die "could not parse line : \"$_\"" unless $host && $disk;
+        $host =~ tr/a-zA-Z0-9._//dc;
+        die "could not parse line : $_" unless $host && $disk;
         $servers{$host}{$disk} = [];
         push @all, $servers{$host}{$disk};
     }
@@ -54,7 +48,7 @@ sub main {
     say '---';
     say 'servers :';
     for my $host (sort keys %servers) {
-        say "- url : $protocol://" . ($host =~ /:\d+$/ ? $host : join(':', $host, $default_port));
+        say "- url : $protocol://$host:$port";
         say "  disks :";
         for my $root (sort keys %{ $servers{$host} }) {
             say "  - root : $root";
@@ -95,14 +89,37 @@ __END__
 
 =head1 NAME
 
-Yars::Command::yars_generate_diskmap - code for yars_generate_diskmap
+Yars::Command::yars_generate_diskmap - generate a mapping from servers + hosts to buckets for yars.
+
+=head1 VERSION
+
+version 0.86
 
 =head1 DESCRIPTION
 
-This module contains the machinery for the command line program L<yars_generate_diskmap>
+This module contains the machinery for the command line program
+L<yars_generate_diskmap>.
 
 =head1 SEE ALSO
 
-L<yars_disk_scan>
+L<yars_generate_diskmap>
+
+=head1 AUTHOR
+
+original author: Marty Brandon
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Brian Duggan
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-=cut
\ No newline at end of file
